@@ -5,7 +5,7 @@ from dateutil.parser import isoparse
 
 @pytest.mark.parametrize("url, expected", [
     ('https://somewhere.com/collections/my_collection/corridor?', 'my_collection'),
-    ('https://somewhere.com/collections/collections/position?', 'collections'),
+    ('https://somewhere.com/v1/collections/collections/position?', 'collections'),
     ('https://somewhere.com/collections/observations/position?', 'observations'),
     ('https://somewhere.com/collections', 'collection name not found in url'),
     ('https://somewhere.com/items/my_collection', 'collection name not found in url'),
@@ -15,7 +15,7 @@ def test_collection_name(url, expected):
     try:
         assert edr.collection_name == expected
     except ValueError as raisedException:
-        assert expected == str(raisedException)
+        assert str(raisedException) == expected
 
 
 @pytest.mark.parametrize("url, expected", [
@@ -32,14 +32,13 @@ def test_collection_name(url, expected):
     ('https://somewhere.com/collections/metar/items/KIAD_2020-05-19T00Z/?', 'items'),
     ('https://somewhere.com/collections/my_collection/not_a_query_type?', 'unsupported query type found in url'),
     ('https://somewhere.com/collections/metar/instances/some_instance/radius?', 'radius'),
-
 ])
 def test_query_type(url, expected):
     edr = EDRQueryParser(url)
     try:
         assert edr.query_type == expected
     except ValueError as raisedException:
-        assert expected == str(raisedException)
+        assert str(raisedException) == expected
 
 
 @pytest.mark.parametrize("url, expected", [
@@ -52,7 +51,7 @@ def test_is_instances(url, expected):
     try:
         assert edr.is_instances == expected
     except ValueError as raisedException:
-        assert expected == str(raisedException)
+        assert str(raisedException) == expected
 
 
 @pytest.mark.parametrize("url, expected", [
@@ -72,7 +71,7 @@ def test_parameter_name(url, expected):
     try:
         assert edr.parameter_name.list == expected
     except ValueError as raisedException:
-        assert expected == str(raisedException)
+        assert str(raisedException) == expected
 
 
 @pytest.mark.parametrize("url, expected", [
@@ -154,7 +153,7 @@ def test_coords_wkt(url, expected):
     try:
         assert edr.coords.wkt == expected
     except ValueError as raisedException:
-        assert expected == str(raisedException)
+        assert str(raisedException) == expected
 
 
 @pytest.mark.parametrize("url, expected", [
@@ -174,7 +173,7 @@ def test_z_float(url, expected):
     try:
         assert edr.z.float == expected
     except ValueError as raisedException:
-        assert expected == str(raisedException)
+        assert str(raisedException) == expected
 
 
 @pytest.mark.parametrize("url, expected", [
@@ -190,7 +189,7 @@ def test_z_interval_from(url, expected):
     try:
         assert edr.z.interval_from == expected
     except ValueError as raisedException:
-        assert expected == str(raisedException)
+        assert str(raisedException) == expected
 
 
 @pytest.mark.parametrize("url, expected", [
@@ -207,7 +206,7 @@ def test_z_interval_to(url, expected):
     try:
         assert edr.z.interval_to == expected
     except ValueError as raisedException:
-        assert expected == str(raisedException)
+        assert str(raisedException) == expected
 
 
 @pytest.mark.parametrize("url, expected", [
@@ -225,7 +224,7 @@ def test_z_is_all(url, expected):
     try:
         assert edr.z.is_all == expected
     except ValueError as raisedException:
-        assert expected == str(raisedException)
+        assert str(raisedException) == expected
 
 
 @pytest.mark.parametrize("url, expected", [
@@ -242,7 +241,7 @@ def test_z_is_list(url, expected):
     try:
         assert edr.z.is_list == expected
     except ValueError as raisedException:
-        assert expected == str(raisedException)
+        assert str(raisedException) == expected
 
 
 @pytest.mark.parametrize("url, expected", [
@@ -258,7 +257,7 @@ def test_z_list(url, expected):
     try:
         assert edr.z.list == expected
     except ValueError as raisedException:
-        assert expected == str(raisedException)
+        assert str(raisedException) == expected
 
 
 @pytest.mark.parametrize("url, expected", [
@@ -275,7 +274,7 @@ def test_z_is_interval(url, expected):
     try:
         assert edr.z.is_interval == expected
     except ValueError as raisedException:
-        assert expected == str(raisedException)
+        assert str(raisedException) == expected
 
 
 @pytest.mark.parametrize("url, expected", [
@@ -290,7 +289,7 @@ def test_coords_coordinates(url, expected):
     try:
         assert edr.coords.coordinates == expected
     except ValueError as raisedException:
-        assert expected == str(raisedException)
+        assert str(raisedException) == expected
 
 
 @pytest.mark.parametrize("url, expected", [
@@ -305,7 +304,7 @@ def test_coords_coords_type(url, expected):
     try:
         assert edr.coords.coords_type == expected
     except ValueError as raisedException:
-        assert expected == str(raisedException)
+        assert str(raisedException) == expected
 
 
 @pytest.mark.parametrize("url, expected", [
@@ -322,7 +321,7 @@ def test_datetime_exact(url, expected):
     try:
         assert edr.datetime.exact == expected
     except ValueError as raisedException:
-        assert expected == str(raisedException)
+        assert str(raisedException) == expected
 
 
 @pytest.mark.parametrize("url, expected", [
@@ -341,7 +340,7 @@ def test_datetime_is_interval(url, expected):
     try:
         assert edr.datetime.is_interval == expected
     except ValueError as raisedException:
-        assert expected == str(raisedException)
+        assert str(raisedException) == expected
 
 
 @pytest.mark.parametrize("url, expected", [
@@ -361,7 +360,7 @@ def test_datetime_interval_from(url, expected):
     try:
         assert edr.datetime.interval_from == expected
     except ValueError as raisedException:
-        assert expected == str(raisedException)
+        assert str(raisedException) == expected
 
 
 @pytest.mark.parametrize("url, expected", [
@@ -377,13 +376,14 @@ def test_datetime_interval_to(url, expected):
     try:
         assert edr.datetime.interval_to == expected
     except ValueError as raisedException:
-        assert expected == str(raisedException)
+        assert str(raisedException) == expected
 
 
 @pytest.mark.parametrize("url, expected", [
     ('https://somewhere.com/collections/my_collection/position?bbox=1,10,20,30', [1, 10, 20, 30]),
     (
-    'https://somewhere.com/collections/my_collection/position?bbox=1,10,20,a', 'could not convert parameter to a list'),
+            'https://somewhere.com/collections/my_collection/position?bbox=1,10,20,a',
+            'could not convert parameter to a list'),
 ])
 def test_bbox(url, expected):
     edr = EDRQueryParser(url)
@@ -391,5 +391,128 @@ def test_bbox(url, expected):
     try:
         assert edr.bbox.list == expected
     except ValueError as raisedException:
-        assert expected == str(raisedException)
+        assert str(raisedException) == expected
 
+
+@pytest.mark.parametrize("url, expected", [
+    ('https://somewhere.com/collections/my_collection/position?within=20&within-units=km', 20),
+    (
+            'https://somewhere.com/collections/my_collection/position?within=30&within-units=km', 30),
+])
+def test_within(url, expected):
+    edr = EDRQueryParser(url)
+
+    try:
+        assert edr.within.value == expected
+    except ValueError as raisedException:
+        assert str(raisedException) == expected
+
+
+@pytest.mark.parametrize("url, expected", [
+    ('https://somewhere.com/collections/my_collection/position?within=20&within-units=km', "km"),
+    (
+            'https://somewhere.com/collections/my_collection/position?within=30&within-units=miles', "miles"),
+])
+def test_within(url, expected):
+    edr = EDRQueryParser(url)
+
+    try:
+        assert edr.within_units.value == expected
+    except ValueError as raisedException:
+        assert str(raisedException) == expected
+
+
+@pytest.mark.parametrize("url, expected", [
+    ('https://somewhere.com/collections/my_collection/position?datetime=..%2F2018-02-12T23%3A20%3A52Z',
+     True),
+    ('https://somewhere.com/collections/my_collection/position?datetime=2018-02-12T23%3A20%3A52Z%2F..',
+     False),
+    ('https://somewhere.com/collections/my_collection/position?datetime=2018-02-12T23%3A20%3A52Z',
+     False),
+])
+def test_datetime_is_less_than(url, expected):
+    edr = EDRQueryParser(url)
+
+    try:
+        assert edr.datetime.is_less_than == expected
+    except ValueError as raisedException:
+        assert str(raisedException) == expected
+
+
+@pytest.mark.parametrize("url, expected", [
+    ('https://somewhere.com/collections/my_collection/position?datetime=..%2F2018-02-12T23%3A20%3A52Z',
+     False),
+    ('https://somewhere.com/collections/my_collection/position?datetime=2018-02-12T23%3A20%3A52Z%2F..',
+     True),
+    ('https://somewhere.com/collections/my_collection/position?datetime=2018-02-12T23%3A20%3A52Z',
+     False),
+])
+def test_datetime_is_greater_than(url, expected):
+    edr = EDRQueryParser(url)
+
+    try:
+        assert edr.datetime.is_greater_than == expected
+    except ValueError as raisedException:
+        assert str(raisedException) == expected
+
+
+@pytest.mark.parametrize("url, expected", [
+    ('https://somewhere.com/collections/my_collection/position?datetime=2018-02-12T23%3A20%3A52Z%2F..',
+     isoparse('2018-02-12T23:20:52Z')),
+    ('https://somewhere.com/collections/my_collection/position?datetime=..%2F2018-02-12T23%3A20%3A52Z',
+     'datetime not a greater than type'),
+    ('https://somewhere.com/collections/my_collection/position?datetime=2018-02-12T23%3A20%3A52Z',
+     'datetime not a greater than type'),
+])
+def test_datetime_greater_than(url, expected):
+    edr = EDRQueryParser(url)
+
+    try:
+        assert edr.datetime.greater_than == expected
+    except ValueError as raisedException:
+        assert str(raisedException) == expected
+
+
+@pytest.mark.parametrize("url, expected", [
+    ('https://somewhere.com/collections/my_collection/position?datetime=..%2F2018-02-12T23%3A20%3A52Z',
+     isoparse('2018-02-12T23:20:52Z')),
+    ('https://somewhere.com/collections/my_collection/position?datetime=2018-02-12T23%3A20%3A52Z%2F..',
+     'datetime not a less than type'),
+    ('https://somewhere.com/collections/my_collection/position?datetime=2018-02-12T23%3A20%3A52Z',
+     'datetime not a less than type'),
+])
+def test_datetime_greater_than(url, expected):
+    edr = EDRQueryParser(url)
+
+    try:
+        assert edr.datetime.less_than == expected
+    except ValueError as raisedException:
+        assert str(raisedException) == expected
+
+
+@pytest.mark.parametrize("url, expected", [
+    ('https://somewhere.com/collections/my_collection/items?next=token123', 'token123'),
+    ('https://somewhere.com/collections/my_collection/items?next=', None),
+    ('https://somewhere.com/collections/my_collection/items', None)
+])
+def test_next(url, expected):
+    edr = EDRQueryParser(url)
+
+    try:
+        assert edr.next.value == expected
+    except ValueError as raisedException:
+        assert str(raisedException) == expected
+
+
+@pytest.mark.parametrize("url, expected", [
+    ('https://somewhere.com/collections/my_collection/items?limit=100', 100),
+    ('https://somewhere.com/collections/my_collection/items?limit=', None),
+    ('https://somewhere.com/collections/my_collection/items', None)
+])
+def test_limit(url, expected):
+    edr = EDRQueryParser(url)
+
+    try:
+        assert edr.limit.value == expected
+    except ValueError as raisedException:
+        assert str(raisedException) == expected
